#
# Copyright (c) 2023, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Optional

from oser.core import Double21436587 as _Double21436587
from oser.core import Double78563412 as _Double78563412
from oser.core import Float2143 as _Float2143
from oser.core import Float3412 as _Float3412
from oser.core import SInt2143 as _SInt2143
from oser.core import SInt21436587 as _SInt21436587
from oser.core import SInt3412 as _SInt3412
from oser.core import SInt78563412 as _SInt78563412
from oser.core import UInt2143 as _UInt2143
from oser.core import UInt21436587 as _UInt21436587
from oser.core import UInt3412 as _UInt3412
from oser.core import UInt78563412 as _UInt78563412
from oser.types import OserElementType, OserStructType, FuzzingValues


class Double21436587(_Double21436587):
    """
    Unsigned, 64-Bit double with modbus endianness: little endian ordered registers with big endian content.
    """

    def __init__(self, value: float = 0.0) -> None:
        """
        Args:
            value: float = 0.0: the initial value.
        """
        super(Double21436587, self).__init__(value=value)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(Double21436587, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(Double21436587, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> float:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(Double21436587, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(Double21436587, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(Double21436587, self).root()

    def set(self, value: float) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(Double21436587, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(Double21436587, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(Double21436587, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(Double21436587, self).up()


class Double78563412(_Double78563412):
    """
    Unsigned, 64-Bit double with modbus endianness: big endian ordered registers with little endian content.
    """

    def __init__(self, value: float = 0.0) -> None:
        """
        Args:
            value: float = 0.0: the initial value.
        """
        super(Double78563412, self).__init__(value=value)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(Double78563412, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(Double78563412, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> float:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(Double78563412, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(Double78563412, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(Double78563412, self).root()

    def set(self, value: float) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(Double78563412, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(Double78563412, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(Double78563412, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(Double78563412, self).up()


class Float2143(_Float2143):
    """
    Unsigned, 32-Bit float with modbus endianness: little endian ordered registers with big endian content.
    """

    def __init__(self, value: float = 0.0) -> None:
        """
        Args:
            value: float = 0.0: the initial value.
        """
        super(Float2143, self).__init__(value=value)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(Float2143, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(Float2143, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> float:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(Float2143, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(Float2143, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(Float2143, self).root()

    def set(self, value: float) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(Float2143, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(Float2143, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(Float2143, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(Float2143, self).up()


class Float3412(_Float3412):
    """
    Unsigned, 32-Bit float with modbus endianness: big endian ordered registers with little endian content.
    """

    def __init__(self, value: float = 0.0) -> None:
        """
        Args:
            value: float = 0.0: the initial value.
        """
        super(Float3412, self).__init__(value=value)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(Float3412, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(Float3412, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> float:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(Float3412, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(Float3412, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(Float3412, self).root()

    def set(self, value: float) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(Float3412, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(Float3412, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(Float3412, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(Float3412, self).up()


class SInt2143(_SInt2143):
    """
    Signed, 32-Bit integer with modbus endianness: little endian ordered registers with big endian content.
    """

    def __init__(self, value: int = 0, format: Optional[str] = None) -> None:
        """
        Args:
            value: the initial value.
            format=None: Use "hex" to format values to hexadecimal.
                Use "bin" to format values to binary.
        """
        super(SInt2143, self).__init__(value=value, format=format)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(SInt2143, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(SInt2143, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> int:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(SInt2143, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(SInt2143, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(SInt2143, self).root()

    def set(self, value: int) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(SInt2143, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(SInt2143, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(SInt2143, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(SInt2143, self).up()


class SInt21436587(_SInt21436587):
    """
    Signed, 64-Bit integer with modbus endianness: little endian ordered registers with big endian content.
    """

    def __init__(self, value: int = 0, format: Optional[str] = None) -> None:
        """
        Args:
            value: the initial value.
            format=None: Use "hex" to format values to hexadecimal.
                Use "bin" to format values to binary.
        """
        super(SInt21436587, self).__init__(value=value, format=format)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(SInt21436587, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(SInt21436587, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> int:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(SInt21436587, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(SInt21436587, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(SInt21436587, self).root()

    def set(self, value: int) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(SInt21436587, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(SInt21436587, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(SInt21436587, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(SInt21436587, self).up()


class SInt3412(_SInt3412):
    """
    Signed, 32-Bit integer with modbus endianness: big endian ordered registers with little endian content.
    """

    def __init__(self, value: int = 0, format: Optional[str] = None) -> None:
        """
        Args:
            value: the initial value.
            format=None: Use "hex" to format values to hexadecimal.
                Use "bin" to format values to binary.
        """
        super(SInt3412, self).__init__(value=value, format=format)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(SInt3412, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(SInt3412, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> int:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(SInt3412, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(SInt3412, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(SInt3412, self).root()

    def set(self, value: int) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(SInt3412, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(SInt3412, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(SInt3412, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(SInt3412, self).up()


class SInt78563412(_SInt78563412):
    """
    Signed, 64-Bit integer with modbus endianness: big endian ordered registers with little endian content.
    """

    def __init__(self, value: int = 0, format: Optional[str] = None) -> None:
        """
        Args:
            value: the initial value.
            format=None: Use "hex" to format values to hexadecimal.
                Use "bin" to format values to binary.
        """
        super(SInt78563412, self).__init__(value=value, format=format)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(SInt78563412, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(SInt78563412, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> int:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(SInt78563412, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(SInt78563412, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(SInt78563412, self).root()

    def set(self, value: int) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(SInt78563412, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(SInt78563412, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(SInt78563412, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(SInt78563412, self).up()


class UInt2143(_UInt2143):
    """
    Unsigned, 32-Bit integer with modbus endianness: little endian ordered registers with big endian content.
    """

    def __init__(self, value: int = 0, format: Optional[str] = None) -> None:
        """
        Args:
            value: the initial value.
            format=None: Use "hex" to format values to hexadecimal.
                Use "bin" to format values to binary.
        """
        super(UInt2143, self).__init__(value=value, format=format)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(UInt2143, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(UInt2143, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> int:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(UInt2143, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(UInt2143, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(UInt2143, self).root()

    def set(self, value: int) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(UInt2143, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(UInt2143, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(UInt2143, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(UInt2143, self).up()


class UInt21436587(_UInt21436587):
    """
    Unsigned, 64-Bit integer with modbus endianness: little endian ordered registers with big endian content.
    """

    def __init__(self, value: int = 0, format: Optional[str] = None) -> None:
        """
        Args:
            value: the initial value.
            format=None: Use "hex" to format values to hexadecimal.
                Use "bin" to format values to binary.
        """
        super(UInt21436587, self).__init__(value=value, format=format)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(UInt21436587, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(UInt21436587, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> int:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(UInt21436587, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(UInt21436587, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(UInt21436587, self).root()

    def set(self, value: int) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(UInt21436587, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(UInt21436587, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(UInt21436587, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(UInt21436587, self).up()


class UInt3412(_UInt3412):
    """
    Unsigned, 32-Bit integer with modbus endianness: big endian ordered registers with little endian content.
    """

    def __init__(self, value: int = 0, format: Optional[str] = None) -> None:
        """
        Args:
            value: the initial value.
            format=None: Use "hex" to format values to hexadecimal.
                Use "bin" to format values to binary.
        """
        super(UInt3412, self).__init__(value=value, format=format)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(UInt3412, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(UInt3412, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> int:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(UInt3412, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(UInt3412, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(UInt3412, self).root()

    def set(self, value: int) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(UInt3412, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(UInt3412, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(UInt3412, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(UInt3412, self).up()


class UInt78563412(_UInt78563412):
    """
    Unsigned, 64-Bit integer with modbus endianness: big endian ordered registers with little endian content.
    """

    def __init__(self, value: int = 0, format: Optional[str] = None) -> None:
        """
        Args:
            value: the initial value.
            format=None: Use "hex" to format values to hexadecimal.
                Use "bin" to format values to binary.
        """
        super(UInt78563412, self).__init__(value=value, format=format)

    def decode(self, data: bytes, full_data: bytes = b"", context_data: bytes = b"") -> int:
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data: the data buffer that is decoded.
            full_data: the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(UInt78563412, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data: bytes = b"", context_data: bytes = b"") -> bytes:
        """
        Return the encoded binary string.

        Args:
            full_data: the binary data string until the part to be encoded.
                The user normally does not need to supply this.
            context_data: the binary data of the current context.
                The user normally does not need to supply this.
        """
        return super(UInt78563412, self).encode(full_data=full_data, context_data=context_data)

    def get(self) -> int:
        """
        Return the value.

        Returns:
            the value.
        """
        return super(UInt78563412, self).get()  # type: ignore

    def introspect(self, stop_at: Optional[OserElementType] = None) -> str:
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None: stop introspection at ``stop_at``.
        """
        return super(UInt78563412, self).introspect(stop_at=stop_at)

    def root(self) -> OserStructType:
        """
        return root element
        """
        return super(UInt78563412, self).root()

    def set(self, value: int) -> None:
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(UInt78563412, self).set(value=value)  # type: ignore

    def set_fuzzing_values(self, values: Optional[FuzzingValues]) -> None:
        """
        Set fuzzing values.

        Args:
            values: the values used for fuzzing.
        """
        return super(UInt78563412, self).set_fuzzing_values(values=values)

    def get_size(self) -> int:
        """
        Return the length of the byte type in bytes.

        Returns:
            int: the length of the byte type in bytes.
        """
        return super(UInt78563412, self).get_size()

    get_byte_size = get_size

    def up(self) -> OserStructType:
        """
        Return the parent element.
        """
        return super(UInt78563412, self).up()
